@@ -1,9 +1,5 @@
-from . import vasp
-from . import lammps
-from . import md
-from .system import System
-from .system import LabeledSystem
-from .system import MultiSystems
+from . import lammps, md, vasp
+from .system import LabeledSystem, MultiSystems, System
 
 try:
     from ._version import version as __version__
@@ -14,11 +10,10 @@ except ImportError:
 try:
     # prevent conflict with dpdata.rdkit
     import rdkit as _
+
     USE_RDKIT = True
 except ModuleNotFoundError:
     USE_RDKIT = False
 
 if USE_RDKIT:
     from .bond_order_system import BondOrderSystem
-
-
