@@ -4,17 +4,18 @@ try:
 except ImportError:
     pass
 
+
 def pick_by_amber_mask(param, maskstr, coords=None):
     """Pick atoms by amber masks
-    
+
     Parameters
     ----------
-    param: str or parmed.Structure
-      filename of Amber param file or parmed.Structure
-    maskstr: str
-      Amber masks
-    coords: np.ndarray (optional)
-      frame coordinates, shape: N*3
+    param : str or parmed.Structure
+        filename of Amber param file or parmed.Structure
+    maskstr : str
+        Amber masks
+    coords : np.ndarray (optional)
+        frame coordinates, shape: N*3
     """
     parm = load_param_file(param)
     if coords is not None:
@@ -22,10 +23,13 @@ def pick_by_amber_mask(param, maskstr, coords=None):
     sele = []
     if len(maskstr) > 0:
         newmaskstr = maskstr.replace("@0", "!@*")
-        sele = [parm.atoms[i].idx for i in parmed.amber.mask.AmberMask(
-            parm, newmaskstr).Selected()]
+        sele = [
+            parm.atoms[i].idx
+            for i in parmed.amber.mask.AmberMask(parm, newmaskstr).Selected()
+        ]
     return sele
 
+
 def load_param_file(param_file):
     if isinstance(param_file, str):
         return parmed.load_file(param_file)
