@@ -1,4 +1,5 @@
 import numpy as np
+
 from dpdata.periodic_table import ELEMENTS
 from dpdata.unit import EnergyConversion
 
@@ -10,10 +11,11 @@ READ_COORDS_START = 3
 READ_COORDS = 6
 READ_FORCES = 7
 
+
 def parse_sqm_out(fname):
-    '''
-        Read atom symbols, charges and coordinates from ambertools sqm.out file
-    '''
+    """
+    Read atom symbols, charges and coordinates from ambertools sqm.out file
+    """
     atom_symbols = []
     coords = []
     charges = []
@@ -55,36 +57,41 @@ def parse_sqm_out(fname):
                 forces.append([float(ll[-60:-40]), float(ll[-40:-20]), float(ll[-20:])])
                 if len(forces) == len(charges):
                     flag = START
-    
+
     data = {}
-    atom_names, data['atom_types'], atom_numbs = np.unique(atom_symbols, return_inverse=True, return_counts=True)
-    data['charges'] = np.array(charges)
-    data['atom_names'] = list(atom_names)
-    data['atom_numbs'] = list(atom_numbs)
-    data['orig'] = np.array([0, 0, 0])
-    data['cells'] = np.array([[[100., 0., 0.], [0., 100., 0.], [0., 0., 100.]]])
-    data['nopbc'] = True
-    data['coords'] = np.array([coords])
+    atom_names, data["atom_types"], atom_numbs = np.unique(
+        atom_symbols, return_inverse=True, return_counts=True
+    )
+    data["charges"] = np.array(charges)
+    data["atom_names"] = list(atom_names)
+    data["atom_numbs"] = list(atom_numbs)
+    data["orig"] = np.array([0, 0, 0])
+    data["cells"] = np.array(
+        [[[100.0, 0.0, 0.0], [0.0, 100.0, 0.0], [0.0, 0.0, 100.0]]]
+    )
+    data["nopbc"] = True
+    data["coords"] = np.array([coords])
 
     energies = np.array(energies)
     forces = -np.array([forces], dtype=np.float64) * kcal2ev
     if len(forces) > 0:
-        data['energies'] = energies
-        data['forces'] = forces
-    
+        data["energies"] = energies
+        data["forces"] = forces
+
     return data
 
+
 def make_sqm_in(data, fname=None, frame_idx=0, **kwargs):
-    symbols = [data['atom_names'][ii] for ii in data['atom_types']]
+    symbols = [data["atom_names"][ii] for ii in data["atom_types"]]
     atomic_numbers = [ELEMENTS.index(ss) + 1 for ss in symbols]
     charge = kwargs.get("charge", 0)
 
     # multiplicity
     mult = kwargs.get("mult", 1)
-    if mult != 1 :
+    if mult != 1:
         raise RuntimeError("Multiplicity is not 1, which is not supported by sqm")
 
-    maxcyc = kwargs.get("maxcyc", 0)    # 0 represents a single-point calculation
+    maxcyc = kwargs.get("maxcyc", 0)  # 0 represents a single-point calculation
     theory = kwargs.get("qm_theory", "DFTB3")
     ret = "Run semi-emperical minimization\n"
     ret += " &qmmm\n"
@@ -93,15 +100,15 @@ def make_sqm_in(data, fname=None, frame_idx=0, **kwargs):
     ret += f"     maxcyc={maxcyc}\n"
     ret += "     verbosity=4\n"
     ret += " /\n"
-    for ii in range(len(data['atom_types'])):
+    for ii in range(len(data["atom_types"])):
         ret += "{:>4s}{:>6s}{:>16s}{:>16s}{:>16s}\n".format(
             str(atomic_numbers[ii]),
             str(symbols[ii]),
             f"{data['coords'][frame_idx][ii, 0]:.6f}",
             f"{data['coords'][frame_idx][ii, 1]:.6f}",
-            f"{data['coords'][frame_idx][ii, 2]:.6f}"
+            f"{data['coords'][frame_idx][ii, 2]:.6f}",
         )
     if fname is not None:
-        with open(fname, 'w') as fp:
+        with open(fname, "w") as fp:
             fp.write(ret)
     return ret
