@@ -14,7 +14,9 @@ class GromacsGroFormat(Format):
         file_name : str
             The input file name
         """
-        return dpdata.gromacs.gro.file_to_system_data(file_name, format_atom_name=format_atom_name, **kwargs)
+        return dpdata.gromacs.gro.file_to_system_data(
+            file_name, format_atom_name=format_atom_name, **kwargs
+        )
 
     def to_system(self, data, file_name=None, frame_idx=-1, **kwargs):
         """
@@ -27,20 +29,20 @@ class GromacsGroFormat(Format):
         frame_idx : int
             The index of the frame to dump
         """
-        assert(frame_idx < len(data['coords']))
+        assert frame_idx < len(data["coords"])
         if frame_idx == -1:
             strs = []
-            for idx in range(data['coords'].shape[0]):
-                gro_str = dpdata.gromacs.gro.from_system_data(data, f_idx=idx,
-                                                              **kwargs)
+            for idx in range(data["coords"].shape[0]):
+                gro_str = dpdata.gromacs.gro.from_system_data(data, f_idx=idx, **kwargs)
                 strs.append(gro_str)
             gro_str = "\n".join(strs)
         else:
             gro_str = dpdata.gromacs.gro.from_system_data(
-                data, f_idx=frame_idx, **kwargs)
+                data, f_idx=frame_idx, **kwargs
+            )
 
         if file_name is None:
             return gro_str
         else:
-            with open(file_name, 'w+') as fp:
+            with open(file_name, "w+") as fp:
                 fp.write(gro_str)
