@@ -7,8 +7,9 @@ class ListFormat(Format):
         """
         convert system to list, usefull for data collection
         """
-        from dpdata import System, LabeledSystem
-        if 'forces' in data:
+        from dpdata import LabeledSystem, System
+
+        if "forces" in data:
             system = LabeledSystem(data=data)
         else:
             system = System(data=data)
