@@ -1,11 +1,12 @@
 from abc import ABC
+
 from scipy import constants
 
-AVOGADRO = constants.Avogadro                             # Avagadro constant
-ELE_CHG  = constants.elementary_charge                    # Elementary Charge, in C
-BOHR     = constants.value("atomic unit of length")       # Bohr, in m
-HARTREE  = constants.value("atomic unit of energy")       # Hartree, in Jole
-RYDBERG  = constants.Rydberg * constants.h * constants.c  # Rydberg, in Jole
+AVOGADRO = constants.Avogadro  # Avagadro constant
+ELE_CHG = constants.elementary_charge  # Elementary Charge, in C
+BOHR = constants.value("atomic unit of length")  # Bohr, in m
+HARTREE = constants.value("atomic unit of energy")  # Hartree, in Jole
+RYDBERG = constants.Rydberg * constants.h * constants.c  # Rydberg, in Jole
 
 # energy conversions
 econvs = {
@@ -15,17 +16,18 @@ econvs = {
     "kcal_mol": 1 / (ELE_CHG * AVOGADRO / 1000 / 4.184),
     "rydberg": RYDBERG / ELE_CHG,
     "J": 1 / ELE_CHG,
-    "kJ": 1000 / ELE_CHG
+    "kJ": 1000 / ELE_CHG,
 }
 
 # length conversions
 lconvs = {
     "angstrom": 1.0,
-    "bohr": BOHR * 1E10,
+    "bohr": BOHR * 1e10,
     "nm": 10.0,
-    "m": 1E10,
+    "m": 1e10,
 }
 
+
 def check_unit(unit):
     if unit not in econvs.keys() and unit not in lconvs.keys():
         try:
@@ -38,6 +40,7 @@ def check_unit(unit):
         except Exception:
             raise RuntimeError(f"Invalid unit: {unit}")
 
+
 class Conversion(ABC):
     def __init__(self, unitA, unitB, check=True):
         """
@@ -45,10 +48,10 @@ class Conversion(ABC):
 
         Parameters
         ----------
-            unitA : str, unit to be converted
-            unitB : str, unit which unitA is converted to, i.e. `1 unitA = self._value unitB`
-            check : bool, whether to check unit validity
-        
+        unitA : str, unit to be converted
+        unitB : str, unit which unitA is converted to, i.e. `1 unitA = self._value unitB`
+        check : bool, whether to check unit validity
+
         Examples
         --------
         >>> conv = Conversion("foo", "bar", check=False)
@@ -64,19 +67,20 @@ class Conversion(ABC):
         self.unitA = unitA
         self.unitB = unitB
         self._value = 0.0
-    
+
     def value(self):
         return self._value
-    
+
     def set_value(self, value):
         self._value = value
-    
+
     def __repr__(self):
         return f"1 {self.unitA} = {self._value} {self.unitB}"
-    
+
     def __str__(self):
         return self.__repr__()
 
+
 class EnergyConversion(Conversion):
     def __init__(self, unitA, unitB):
         """
@@ -91,6 +95,7 @@ class EnergyConversion(Conversion):
         super().__init__(unitA, unitB)
         self.set_value(econvs[unitA] / econvs[unitB])
 
+
 class LengthConversion(Conversion):
     def __init__(self, unitA, unitB):
         """
@@ -105,6 +110,7 @@ class LengthConversion(Conversion):
         super().__init__(unitA, unitB)
         self.set_value(lconvs[unitA] / lconvs[unitB])
 
+
 class ForceConversion(Conversion):
     def __init__(self, unitA, unitB):
         """
@@ -112,7 +118,7 @@ class ForceConversion(Conversion):
 
         Parameters
         ----------
-            unitA, unitB : str, in format of "energy_unit/length_unit"
+        unitA, unitB : str, in format of "energy_unit/length_unit"
 
         Examples
         --------
@@ -125,6 +131,7 @@ class ForceConversion(Conversion):
         lconv = LengthConversion(unitA.split("/")[1], unitB.split("/")[1]).value()
         self.set_value(econv / lconv)
 
+
 class PressureConversion(Conversion):
     def __init__(self, unitA, unitB):
         """
@@ -132,7 +139,7 @@ class PressureConversion(Conversion):
 
         Parameters
         ----------
-            unitA, unitB : str, in format of "energy_unit/length_unit^3", or in `["Pa", "pa", "kPa", "kpa", "bar", "kbar"]`
+        unitA, unitB : str, in format of "energy_unit/length_unit^3", or in `["Pa", "pa", "kPa", "kpa", "bar", "kbar"]`
 
         Examples
         --------
@@ -148,18 +155,18 @@ class PressureConversion(Conversion):
         econv = EnergyConversion(eunitA, eunitB).value() * factorA / factorB
         lconv = LengthConversion(lunitA, lunitB).value()
         self.set_value(econv / lconv**3)
-    
+
     def _convert_unit(self, unit):
         if unit == "Pa" or unit == "pa":
             return "J/m^3", 1
         elif unit == "kPa" or unit == "kpa":
             return "kJ/m^3", 1
         elif unit == "GPa" or unit == "Gpa":
-            return "kJ/m^3", 1E6
+            return "kJ/m^3", 1e6
         elif unit == "bar":
-            return "J/m^3", 1E5
+            return "J/m^3", 1e5
         elif unit == "kbar":
-            return "kJ/m^3", 1E5
+            return "kJ/m^3", 1e5
         else:
             return unit, 1
 
