@@ -2,21 +2,22 @@ from typing import Tuple
 
 import numpy as np
 
-def coord_to_xyz(coord: np.ndarray, types: list)->str:
+
+def coord_to_xyz(coord: np.ndarray, types: list) -> str:
     """Convert coordinates and types to xyz format.
-    
+
     Parameters
     ----------
-    coord: np.ndarray
+    coord : np.ndarray
         coordinates, Nx3 array
-    types: list
+    types : list
         list of types
-    
+
     Returns
     -------
     str
         xyz format string
-    
+
     Examples
     --------
     >>> coord_to_xyz(np.ones((1,3)), ["C"])
@@ -24,7 +25,7 @@ def coord_to_xyz(coord: np.ndarray, types: list)->str:
 
     C 1.000000 1.000000 1.000000
     """
-    buff = [str(len(types)), '']
+    buff = [str(len(types)), ""]
     for at, cc in zip(types, coord):
         buff.append("{} {:.6f} {:.6f} {:.6f}".format(at, *cc))
     return "\n".join(buff)
@@ -47,7 +48,7 @@ def xyz_to_coord(xyz: str) -> Tuple[np.ndarray, list]:
     """
     symbols = []
     coords = []
-    for ii, line in enumerate(xyz.split('\n')):
+    for ii, line in enumerate(xyz.split("\n")):
         if ii == 0:
             natoms = int(line.strip())
         elif 2 <= ii <= 1 + natoms:
@@ -56,4 +57,3 @@ def xyz_to_coord(xyz: str) -> Tuple[np.ndarray, list]:
             coords.append((float(x), float(y), float(z)))
             symbols.append(symbol)
     return np.array(coords), symbols
-
