@@ -1,13 +1,14 @@
 import os
-import numpy as np
 import unittest
-from context import dpdata
+
+import numpy as np
 from comp_sys import CompLabeledSys, IsPBC
+from context import dpdata
+
 
 class TestToList(unittest.TestCase, CompLabeledSys, IsPBC):
-    def setUp (self) :
-        system = dpdata.LabeledSystem('poscars/OUTCAR.h2o.md',
-                                             fmt = 'vasp/outcar')
+    def setUp(self):
+        system = dpdata.LabeledSystem("poscars/OUTCAR.h2o.md", fmt="vasp/outcar")
         self.system_1 = system.sub_system([2])
         self.system_2 = system.to_list()[2]
         self.places = 6
@@ -16,5 +17,5 @@ class TestToList(unittest.TestCase, CompLabeledSys, IsPBC):
         self.v_places = 4
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
